@@ -152,7 +152,7 @@ def Translate(text, langCombo):
                 'lang': langCombo,
                 'text': text
                 },
-            timeout = 0.5
+            timeout = 3
         )
     except requests.Timeout:
         PrYellow('A request timed out!')
